@@ -116,8 +116,10 @@ mode);
 				     int *outlen, formtype *typeform,
 				     char *spacing, int *outputPos,
 				     int *inputPos, int *cursorPos, int mode);
-  void EXPORT_CALL lou_logPrint (char *format, ...);
-/* prints error messages to a file */
+  void EXPORT_CALL lou_logPrint (const char *format, ...);
+/* Prints error messages to a file
+   @deprecated As of 2.6.0, applications using liblouis should implement
+               their own logging system. */
 
   void EXPORT_CALL lou_logFile (const char *filename);
 /* Specifies the name of the file to be used by lou_logPrint. If it is 
@@ -153,6 +155,24 @@ void EXPORT_CALL lou_registerTableResolver (char ** (* resolver) (const char *ta
 //  char EXPORT_CALL * lou_getTablePaths ();
   /* Get a list of paths actually used in seraching for tables */
 
+typedef void (*logcallback)(int level, const char *message);
+  void EXPORT_CALL lou_registerLogCallback(logcallback callback);
+/* Register logging callbacks
+ * Set to NULL for default callback.
+ */
+
+  typedef enum
+  {
+    LOG_ALL = -2147483648,
+    LOG_DEBUG = 10000,
+    LOG_INFO = 20000,
+    LOG_WARN = 30000,
+    LOG_ERROR = 40000,
+    LOG_FATAL = 50000,
+    LOG_OFF = 2147483647
+  } logLevels;
+  void EXPORT_CALL lou_setLogLevel(logLevels level);
+/* Set the level for logging callback to be called at */
   void EXPORT_CALL lou_free ();
 /* This function should be called at the end of 
 * the application to free all memory allocated by liblouis. */
